#include <stdio.h>
#include <stdarg.h>

#include "unzipapi.h"

void fatal(char *msg);
int warning(char *msg, ...);
int listout(char *name);
int scale(unsigned long, unsigned long);

int main(int argc, char *argv[])
{
  if (UnzipInit(warning, listout, scale) != 0)
    fatal("UnzipInit failed.");

  {
    char *args[7];

    args[0] = "unzip.dll";
    args[1] = "-o";
    args[2] = "-i";
    args[3] = "f:\\test";
    args[4] = "-l";
    args[5] = "c:\\lanlk";
    args[6] = NULL;

    if (UnzipArgs(6, args))
      fatal("UnzipArgs failed.");
  }

  {
    unsigned long unpacked, totalsize;
    int rc;

    unpacked = 0l;
    totalsize = 100000l;
    if ((rc = Unzip("foo.zip", &unpacked, totalsize)))
      printf("Unzip returned %d.", rc);
  }
}

void fatal(char *msg)
{
  printf("FATAL: %s\n", msg);
  exit(-1);
}

int warning(char *msg, ...)
{
  va_list args;

  va_start(args, msg);
  printf("WARNING: ");
  vprintf(msg, args);
  printf("\n");
  va_end(args);

  return 0;
}

int listout(char *name)
{
  printf("UNZIPPED: \"%s\"\n", name);
  return 0;
}

int scale(unsigned long unpacked, unsigned long total)
{
  printf("SCALE: %ld/%ld\n", unpacked, total);
  return 0;
}

